[Lldb-commits] [lldb] r242762 - [lldb-mi] size_t rather than MIuint for arg counts.

Bruce Mitchener bruce.mitchener at gmail.com
Tue Jul 21 01:07:27 PDT 2015


Author: brucem
Date: Tue Jul 21 03:07:27 2015
New Revision: 242762

URL: http://llvm.org/viewvc/llvm-project?rev=242762&view=rev
Log:
[lldb-mi] size_t rather than MIuint for arg counts.

Summary: [lldb-mi] size_t rather than MIuint for arg counts.

Reviewers: abidh, ki.stfu

Subscribers: lldb-commits

Differential Revision: http://reviews.llvm.org/D11049

Modified:
    lldb/trunk/tools/lldb-mi/MICmdArgContext.cpp
    lldb/trunk/tools/lldb-mi/MICmdArgContext.h
    lldb/trunk/tools/lldb-mi/MICmdArgSet.cpp
    lldb/trunk/tools/lldb-mi/MICmdArgSet.h

Modified: lldb/trunk/tools/lldb-mi/MICmdArgContext.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdArgContext.cpp?rev=242762&r1=242761&r2=242762&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdArgContext.h (original)
+++ lldb/trunk/tools/lldb-mi/MICmdArgContext.h Tue Jul 21 03:07:27 2015
@@ -28,11 +28,11 @@ class CMICmdArgContext
     /* ctor */ CMICmdArgContext(const CMIUtilString &vrCmdLineArgsRaw);
     //
     const CMIUtilString &GetArgsLeftToParse(void) const;
-    MIuint GetNumberArgsPresent(void) const;
+    size_t GetNumberArgsPresent(void) const;
     CMIUtilString::VecString_t GetArgs(void) const;
     bool IsEmpty(void) const;
     bool RemoveArg(const CMIUtilString &vArg);
-    bool RemoveArgAtPos(const CMIUtilString &vArg, const MIuint nArgIndex);
+    bool RemoveArgAtPos(const CMIUtilString &vArg, size_t nArgIndex);
     //
     CMICmdArgContext &operator=(const CMICmdArgContext &vOther);
 

Modified: lldb/trunk/tools/lldb-mi/MICmdArgSet.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdArgSet.cpp?rev=242762&r1=242761&r2=242762&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdArgSet.h (original)
+++ lldb/trunk/tools/lldb-mi/MICmdArgSet.h Tue Jul 21 03:07:27 2015
@@ -67,7 +67,7 @@ class CMICmdArgSet : public CMICmnBase
     bool GetArg(const CMIUtilString &vArgName, CMICmdArgValBase *&vpArg) const;
     const SetCmdArgs_t &GetArgsThatAreMissing(void) const;
     const SetCmdArgs_t &GetArgsThatInvalid(void) const;
-    MIuint GetCount(void) const;
+    size_t GetCount(void) const;
     bool IsArgContextEmpty(void) const;
     bool IsArgsPresentButNotHandledByCmd(void) const;
     void WarningArgsNotHandledbyCmdLogFile(const CMIUtilString &vrCmdName);





More information about the lldb-commits mailing list
--- lldb/trunk/tools/lldb-mi/MICmdArgContext.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmdArgContext.cpp Tue Jul 21 03:07:27 2015
@@ -149,9 +149,9 @@ CMICmdArgContext::RemoveArg(const CMIUti
 // Throws:  None.
 //--
 bool
-CMICmdArgContext::RemoveArgAtPos(const CMIUtilString &vArg, const MIuint nArgIndex)
+CMICmdArgContext::RemoveArgAtPos(const CMIUtilString &vArg, size_t nArgIndex)
 {
-    MIuint nWordIndex = 0;
+    size_t nWordIndex = 0;
     CMIUtilString strBuildContextUp;
     const CMIUtilString::VecString_t vecWords(GetArgs());
     const bool bSpaceRequired(GetNumberArgsPresent() > 2);
@@ -202,10 +202,10 @@ CMICmdArgContext::RemoveArgAtPos(const C
 // Details: Retrieve number of arguments or options present in the command's option text.
 // Type:    Method.
 // Args:    None.
 // Return:  MIuint  - 0 to n arguments present.
 // Throws:  None.
 //--
-MIuint
+size_t
 CMICmdArgContext::GetNumberArgsPresent(void) const
 {
     CMIUtilString::VecString_t vecOptions;
@@ -202,10 +202,10 @@ CMICmdArgContext::RemoveArgAtPos(const C
 // Type:    Method.
 // Args:    None.
-// Return:  MIuint  - 0 to n arguments present.
+// Return:  size_t  - 0 to n arguments present.
 // Throws:  None.
 //--

Modified: lldb/trunk/tools/lldb-mi/MICmdArgContext.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdArgContext.h?rev=242762&r1=242761&r2=242762&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdArgSet.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmdArgSet.cpp Tue Jul 21 03:07:27 2015
@@ -335,10 +335,10 @@ CMICmdArgSet::IsArgContextEmpty(void) co
 // Details: Retrieve the number of arguments that are being used for the command.
 // Type:    Method.
 // Args:    None.
 // Return:  MIuint - Argument count.
 // Throws:  None.
 //--
-MIuint
+size_t
 CMICmdArgSet::GetCount(void) const
 {
     return m_setCmdArgs.size();
@@ -335,10 +335,10 @@ CMICmdArgSet::IsArgContextEmpty(void) co
 // Type:    Method.
 // Args:    None.
-// Return:  MIuint - Argument count.
+// Return:  size_t - Argument count.
 // Throws:  None.
 //--

Modified: lldb/trunk/tools/lldb-mi/MICmdArgSet.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdArgSet.h?rev=242762&r1=242761&r2=242762&view=diff
==============================================================================